// 9x16-bit cosine table with 2^9=512 steps
module cosineTable9x16bit (CLK, cosine_addr, cosine_out);
   input CLK;
   wire  CLK;
   input [8:0] cosine_addr;
   wire [8:0]  cosine_addr;
   output [15:0] cosine_out;
   reg [15:0]    cosine_out;

   always @(posedge CLK) begin
      case(cosine_addr)
        9'h000: cosine_out = 16'h4000; // addr = 0, cosine_out = 0x10000 = 1.000000
        9'h001: cosine_out = 16'h3ffe; // addr = 1, cosine_out = 0x0fffb = 0.999925
        9'h002: cosine_out = 16'h3ffb; // addr = 2, cosine_out = 0x0ffec = 0.999699
        9'h003: cosine_out = 16'h3ff4; // addr = 3, cosine_out = 0x0ffd3 = 0.999322
        9'h004: cosine_out = 16'h3fec; // addr = 4, cosine_out = 0x0ffb1 = 0.998795
        9'h005: cosine_out = 16'h3fe1; // addr = 5, cosine_out = 0x0ff84 = 0.998118
        9'h006: cosine_out = 16'h3fd3; // addr = 6, cosine_out = 0x0ff4e = 0.997290
        9'h007: cosine_out = 16'h3fc3; // addr = 7, cosine_out = 0x0ff0e = 0.996313
        9'h008: cosine_out = 16'h3fb1; // addr = 8, cosine_out = 0x0fec4 = 0.995185
        9'h009: cosine_out = 16'h3f9c; // addr = 9, cosine_out = 0x0fe70 = 0.993907
        9'h00a: cosine_out = 16'h3f84; // addr = 10, cosine_out = 0x0fe13 = 0.992480
        9'h00b: cosine_out = 16'h3f6a; // addr = 11, cosine_out = 0x0fdab = 0.990903
        9'h00c: cosine_out = 16'h3f4e; // addr = 12, cosine_out = 0x0fd3a = 0.989177
        9'h00d: cosine_out = 16'h3f2f; // addr = 13, cosine_out = 0x0fcbf = 0.987301
        9'h00e: cosine_out = 16'h3f0e; // addr = 14, cosine_out = 0x0fc3b = 0.985278
        9'h00f: cosine_out = 16'h3eeb; // addr = 15, cosine_out = 0x0fbac = 0.983105
        9'h010: cosine_out = 16'h3ec5; // addr = 16, cosine_out = 0x0fb14 = 0.980785
        9'h011: cosine_out = 16'h3e9c; // addr = 17, cosine_out = 0x0fa73 = 0.978317
        9'h012: cosine_out = 16'h3e71; // addr = 18, cosine_out = 0x0f9c7 = 0.975702
        9'h013: cosine_out = 16'h3e44; // addr = 19, cosine_out = 0x0f912 = 0.972940
        9'h014: cosine_out = 16'h3e14; // addr = 20, cosine_out = 0x0f853 = 0.970031
        9'h015: cosine_out = 16'h3de2; // addr = 21, cosine_out = 0x0f78b = 0.966976
        9'h016: cosine_out = 16'h3dae; // addr = 22, cosine_out = 0x0f6ba = 0.963776
        9'h017: cosine_out = 16'h3d77; // addr = 23, cosine_out = 0x0f5de = 0.960431
        9'h018: cosine_out = 16'h3d3e; // addr = 24, cosine_out = 0x0f4fa = 0.956940
        9'h019: cosine_out = 16'h3d02; // addr = 25, cosine_out = 0x0f40b = 0.953306
        9'h01a: cosine_out = 16'h3cc5; // addr = 26, cosine_out = 0x0f314 = 0.949528
        9'h01b: cosine_out = 16'h3c84; // addr = 27, cosine_out = 0x0f213 = 0.945607
        9'h01c: cosine_out = 16'h3c42; // addr = 28, cosine_out = 0x0f109 = 0.941544
        9'h01d: cosine_out = 16'h3bfd; // addr = 29, cosine_out = 0x0eff5 = 0.937339
        9'h01e: cosine_out = 16'h3bb6; // addr = 30, cosine_out = 0x0eed8 = 0.932993
        9'h01f: cosine_out = 16'h3b6c; // addr = 31, cosine_out = 0x0edb2 = 0.928506
        9'h020: cosine_out = 16'h3b20; // addr = 32, cosine_out = 0x0ec83 = 0.923880
        9'h021: cosine_out = 16'h3ad2; // addr = 33, cosine_out = 0x0eb4b = 0.919114
        9'h022: cosine_out = 16'h3a82; // addr = 34, cosine_out = 0x0ea09 = 0.914210
        9'h023: cosine_out = 16'h3a2f; // addr = 35, cosine_out = 0x0e8bf = 0.909168
        9'h024: cosine_out = 16'h39da; // addr = 36, cosine_out = 0x0e76b = 0.903989
        9'h025: cosine_out = 16'h3983; // addr = 37, cosine_out = 0x0e60f = 0.898674
        9'h026: cosine_out = 16'h392a; // addr = 38, cosine_out = 0x0e4aa = 0.893224
        9'h027: cosine_out = 16'h38cf; // addr = 39, cosine_out = 0x0e33c = 0.887640
        9'h028: cosine_out = 16'h3871; // addr = 40, cosine_out = 0x0e1c5 = 0.881921
        9'h029: cosine_out = 16'h3811; // addr = 41, cosine_out = 0x0e046 = 0.876070
        9'h02a: cosine_out = 16'h37af; // addr = 42, cosine_out = 0x0debe = 0.870087
        9'h02b: cosine_out = 16'h374b; // addr = 43, cosine_out = 0x0dd2d = 0.863973
        9'h02c: cosine_out = 16'h36e5; // addr = 44, cosine_out = 0x0db94 = 0.857729
        9'h02d: cosine_out = 16'h367c; // addr = 45, cosine_out = 0x0d9f2 = 0.851355
        9'h02e: cosine_out = 16'h3612; // addr = 46, cosine_out = 0x0d848 = 0.844854
        9'h02f: cosine_out = 16'h35a5; // addr = 47, cosine_out = 0x0d695 = 0.838225
        9'h030: cosine_out = 16'h3536; // addr = 48, cosine_out = 0x0d4db = 0.831470
        9'h031: cosine_out = 16'h34c6; // addr = 49, cosine_out = 0x0d318 = 0.824589
        9'h032: cosine_out = 16'h3453; // addr = 50, cosine_out = 0x0d14d = 0.817585
        9'h033: cosine_out = 16'h33de; // addr = 51, cosine_out = 0x0cf7a = 0.810457
        9'h034: cosine_out = 16'h3367; // addr = 52, cosine_out = 0x0cd9f = 0.803208
        9'h035: cosine_out = 16'h32ee; // addr = 53, cosine_out = 0x0cbbb = 0.795837
        9'h036: cosine_out = 16'h3274; // addr = 54, cosine_out = 0x0c9d1 = 0.788346
        9'h037: cosine_out = 16'h31f7; // addr = 55, cosine_out = 0x0c7de = 0.780737
        9'h038: cosine_out = 16'h3179; // addr = 56, cosine_out = 0x0c5e4 = 0.773010
        9'h039: cosine_out = 16'h30f8; // addr = 57, cosine_out = 0x0c3e2 = 0.765167
        9'h03a: cosine_out = 16'h3076; // addr = 58, cosine_out = 0x0c1d8 = 0.757209
        9'h03b: cosine_out = 16'h2ff1; // addr = 59, cosine_out = 0x0bfc7 = 0.749136
        9'h03c: cosine_out = 16'h2f6b; // addr = 60, cosine_out = 0x0bdae = 0.740951
        9'h03d: cosine_out = 16'h2ee3; // addr = 61, cosine_out = 0x0bb8f = 0.732654
        9'h03e: cosine_out = 16'h2e5a; // addr = 62, cosine_out = 0x0b968 = 0.724247
        9'h03f: cosine_out = 16'h2dce; // addr = 63, cosine_out = 0x0b73a = 0.715731
        9'h040: cosine_out = 16'h2d41; // addr = 64, cosine_out = 0x0b504 = 0.707107
        9'h041: cosine_out = 16'h2cb2; // addr = 65, cosine_out = 0x0b2c8 = 0.698376
        9'h042: cosine_out = 16'h2c21; // addr = 66, cosine_out = 0x0b085 = 0.689541
        9'h043: cosine_out = 16'h2b8e; // addr = 67, cosine_out = 0x0ae3b = 0.680601
        9'h044: cosine_out = 16'h2afa; // addr = 68, cosine_out = 0x0abeb = 0.671559
        9'h045: cosine_out = 16'h2a65; // addr = 69, cosine_out = 0x0a994 = 0.662416
        9'h046: cosine_out = 16'h29cd; // addr = 70, cosine_out = 0x0a736 = 0.653173
        9'h047: cosine_out = 16'h2934; // addr = 71, cosine_out = 0x0a4d2 = 0.643832
        9'h048: cosine_out = 16'h2899; // addr = 72, cosine_out = 0x0a267 = 0.634393
        9'h049: cosine_out = 16'h27fd; // addr = 73, cosine_out = 0x09ff6 = 0.624860
        9'h04a: cosine_out = 16'h275f; // addr = 74, cosine_out = 0x09d7f = 0.615232
        9'h04b: cosine_out = 16'h26c0; // addr = 75, cosine_out = 0x09b02 = 0.605511
        9'h04c: cosine_out = 16'h261f; // addr = 76, cosine_out = 0x0987f = 0.595699
        9'h04d: cosine_out = 16'h257d; // addr = 77, cosine_out = 0x095f6 = 0.585798
        9'h04e: cosine_out = 16'h24da; // addr = 78, cosine_out = 0x09368 = 0.575808
        9'h04f: cosine_out = 16'h2434; // addr = 79, cosine_out = 0x090d3 = 0.565732
        9'h050: cosine_out = 16'h238e; // addr = 80, cosine_out = 0x08e39 = 0.555570
        9'h051: cosine_out = 16'h22e6; // addr = 81, cosine_out = 0x08b9a = 0.545325
        9'h052: cosine_out = 16'h223d; // addr = 82, cosine_out = 0x088f5 = 0.534998
        9'h053: cosine_out = 16'h2192; // addr = 83, cosine_out = 0x0864b = 0.524590
        9'h054: cosine_out = 16'h20e7; // addr = 84, cosine_out = 0x0839c = 0.514103
        9'h055: cosine_out = 16'h2039; // addr = 85, cosine_out = 0x080e7 = 0.503538
        9'h056: cosine_out = 16'h1f8b; // addr = 86, cosine_out = 0x07e2e = 0.492898
        9'h057: cosine_out = 16'h1edc; // addr = 87, cosine_out = 0x07b70 = 0.482184
        9'h058: cosine_out = 16'h1e2b; // addr = 88, cosine_out = 0x078ad = 0.471397
        9'h059: cosine_out = 16'h1d79; // addr = 89, cosine_out = 0x075e5 = 0.460539
        9'h05a: cosine_out = 16'h1cc6; // addr = 90, cosine_out = 0x07319 = 0.449611
        9'h05b: cosine_out = 16'h1c12; // addr = 91, cosine_out = 0x07049 = 0.438616
        9'h05c: cosine_out = 16'h1b5d; // addr = 92, cosine_out = 0x06d74 = 0.427555
        9'h05d: cosine_out = 16'h1aa6; // addr = 93, cosine_out = 0x06a9b = 0.416430
        9'h05e: cosine_out = 16'h19ef; // addr = 94, cosine_out = 0x067bd = 0.405241
        9'h05f: cosine_out = 16'h1937; // addr = 95, cosine_out = 0x064dc = 0.393992
        9'h060: cosine_out = 16'h187d; // addr = 96, cosine_out = 0x061f7 = 0.382683
        9'h061: cosine_out = 16'h17c3; // addr = 97, cosine_out = 0x05f0e = 0.371317
        9'h062: cosine_out = 16'h1708; // addr = 98, cosine_out = 0x05c22 = 0.359895
        9'h063: cosine_out = 16'h164c; // addr = 99, cosine_out = 0x05931 = 0.348419
        9'h064: cosine_out = 16'h158f; // addr = 100, cosine_out = 0x0563e = 0.336890
        9'h065: cosine_out = 16'h14d1; // addr = 101, cosine_out = 0x05347 = 0.325310
        9'h066: cosine_out = 16'h1413; // addr = 102, cosine_out = 0x0504d = 0.313682
        9'h067: cosine_out = 16'h1354; // addr = 103, cosine_out = 0x04d50 = 0.302006
        9'h068: cosine_out = 16'h1294; // addr = 104, cosine_out = 0x04a50 = 0.290285
        9'h069: cosine_out = 16'h11d3; // addr = 105, cosine_out = 0x0474d = 0.278520
        9'h06a: cosine_out = 16'h1111; // addr = 106, cosine_out = 0x04447 = 0.266713
        9'h06b: cosine_out = 16'h104f; // addr = 107, cosine_out = 0x0413e = 0.254866
        9'h06c: cosine_out = 16'h0f8c; // addr = 108, cosine_out = 0x03e33 = 0.242980
        9'h06d: cosine_out = 16'h0ec9; // addr = 109, cosine_out = 0x03b26 = 0.231058
        9'h06e: cosine_out = 16'h0e05; // addr = 110, cosine_out = 0x03817 = 0.219101
        9'h06f: cosine_out = 16'h0d41; // addr = 111, cosine_out = 0x03505 = 0.207111
        9'h070: cosine_out = 16'h0c7c; // addr = 112, cosine_out = 0x031f1 = 0.195090
        9'h071: cosine_out = 16'h0bb6; // addr = 113, cosine_out = 0x02edb = 0.183040
        9'h072: cosine_out = 16'h0af1; // addr = 114, cosine_out = 0x02bc4 = 0.170962
        9'h073: cosine_out = 16'h0a2a; // addr = 115, cosine_out = 0x028aa = 0.158858
        9'h074: cosine_out = 16'h0964; // addr = 116, cosine_out = 0x02590 = 0.146730
        9'h075: cosine_out = 16'h089c; // addr = 117, cosine_out = 0x02273 = 0.134581
        9'h076: cosine_out = 16'h07d5; // addr = 118, cosine_out = 0x01f56 = 0.122411
        9'h077: cosine_out = 16'h070d; // addr = 119, cosine_out = 0x01c37 = 0.110222
        9'h078: cosine_out = 16'h0645; // addr = 120, cosine_out = 0x01917 = 0.098017
        9'h079: cosine_out = 16'h057d; // addr = 121, cosine_out = 0x015f6 = 0.085797
        9'h07a: cosine_out = 16'h04b5; // addr = 122, cosine_out = 0x012d5 = 0.073565
        9'h07b: cosine_out = 16'h03ec; // addr = 123, cosine_out = 0x00fb2 = 0.061321
        9'h07c: cosine_out = 16'h0323; // addr = 124, cosine_out = 0x00c8f = 0.049068
        9'h07d: cosine_out = 16'h025b; // addr = 125, cosine_out = 0x0096c = 0.036807
        9'h07e: cosine_out = 16'h0192; // addr = 126, cosine_out = 0x00648 = 0.024541
        9'h07f: cosine_out = 16'h00c9; // addr = 127, cosine_out = 0x00324 = 0.012272
        9'h080: cosine_out = 16'h0000; // addr = 128, cosine_out = 0x00000 = 0.000000
        9'h081: cosine_out = 16'hff37; // addr = 129, cosine_out = 0x3fcdc = -0.012272
        9'h082: cosine_out = 16'hfe6e; // addr = 130, cosine_out = 0x3f9b8 = -0.024541
        9'h083: cosine_out = 16'hfda5; // addr = 131, cosine_out = 0x3f694 = -0.036807
        9'h084: cosine_out = 16'hfcdc; // addr = 132, cosine_out = 0x3f371 = -0.049068
        9'h085: cosine_out = 16'hfc13; // addr = 133, cosine_out = 0x3f04e = -0.061321
        9'h086: cosine_out = 16'hfb4a; // addr = 134, cosine_out = 0x3ed2b = -0.073565
        9'h087: cosine_out = 16'hfa82; // addr = 135, cosine_out = 0x3ea0a = -0.085797
        9'h088: cosine_out = 16'hf9ba; // addr = 136, cosine_out = 0x3e6e9 = -0.098017
        9'h089: cosine_out = 16'hf8f2; // addr = 137, cosine_out = 0x3e3c9 = -0.110222
        9'h08a: cosine_out = 16'hf82a; // addr = 138, cosine_out = 0x3e0aa = -0.122411
        9'h08b: cosine_out = 16'hf763; // addr = 139, cosine_out = 0x3dd8d = -0.134581
        9'h08c: cosine_out = 16'hf69c; // addr = 140, cosine_out = 0x3da70 = -0.146730
        9'h08d: cosine_out = 16'hf5d5; // addr = 141, cosine_out = 0x3d756 = -0.158858
        9'h08e: cosine_out = 16'hf50f; // addr = 142, cosine_out = 0x3d43c = -0.170962
        9'h08f: cosine_out = 16'hf449; // addr = 143, cosine_out = 0x3d125 = -0.183040
        9'h090: cosine_out = 16'hf383; // addr = 144, cosine_out = 0x3ce0f = -0.195090
        9'h091: cosine_out = 16'hf2be; // addr = 145, cosine_out = 0x3cafb = -0.207111
        9'h092: cosine_out = 16'hf1fa; // addr = 146, cosine_out = 0x3c7e9 = -0.219101
        9'h093: cosine_out = 16'hf136; // addr = 147, cosine_out = 0x3c4da = -0.231058
        9'h094: cosine_out = 16'hf073; // addr = 148, cosine_out = 0x3c1cd = -0.242980
        9'h095: cosine_out = 16'hefb0; // addr = 149, cosine_out = 0x3bec2 = -0.254866
        9'h096: cosine_out = 16'heeee; // addr = 150, cosine_out = 0x3bbb9 = -0.266713
        9'h097: cosine_out = 16'hee2c; // addr = 151, cosine_out = 0x3b8b3 = -0.278520
        9'h098: cosine_out = 16'hed6c; // addr = 152, cosine_out = 0x3b5b0 = -0.290285
        9'h099: cosine_out = 16'hecac; // addr = 153, cosine_out = 0x3b2b0 = -0.302006
        9'h09a: cosine_out = 16'hebec; // addr = 154, cosine_out = 0x3afb3 = -0.313682
        9'h09b: cosine_out = 16'heb2e; // addr = 155, cosine_out = 0x3acb9 = -0.325310
        9'h09c: cosine_out = 16'hea70; // addr = 156, cosine_out = 0x3a9c2 = -0.336890
        9'h09d: cosine_out = 16'he9b3; // addr = 157, cosine_out = 0x3a6cf = -0.348419
        9'h09e: cosine_out = 16'he8f7; // addr = 158, cosine_out = 0x3a3de = -0.359895
        9'h09f: cosine_out = 16'he83c; // addr = 159, cosine_out = 0x3a0f2 = -0.371317
        9'h0a0: cosine_out = 16'he782; // addr = 160, cosine_out = 0x39e09 = -0.382683
        9'h0a1: cosine_out = 16'he6c9; // addr = 161, cosine_out = 0x39b24 = -0.393992
        9'h0a2: cosine_out = 16'he610; // addr = 162, cosine_out = 0x39843 = -0.405241
        9'h0a3: cosine_out = 16'he559; // addr = 163, cosine_out = 0x39565 = -0.416430
        9'h0a4: cosine_out = 16'he4a3; // addr = 164, cosine_out = 0x3928c = -0.427555
        9'h0a5: cosine_out = 16'he3ed; // addr = 165, cosine_out = 0x38fb7 = -0.438616
        9'h0a6: cosine_out = 16'he339; // addr = 166, cosine_out = 0x38ce7 = -0.449611
        9'h0a7: cosine_out = 16'he286; // addr = 167, cosine_out = 0x38a1b = -0.460539
        9'h0a8: cosine_out = 16'he1d4; // addr = 168, cosine_out = 0x38753 = -0.471397
        9'h0a9: cosine_out = 16'he124; // addr = 169, cosine_out = 0x38490 = -0.482184
        9'h0aa: cosine_out = 16'he074; // addr = 170, cosine_out = 0x381d2 = -0.492898
        9'h0ab: cosine_out = 16'hdfc6; // addr = 171, cosine_out = 0x37f19 = -0.503538
        9'h0ac: cosine_out = 16'hdf19; // addr = 172, cosine_out = 0x37c64 = -0.514103
        9'h0ad: cosine_out = 16'hde6d; // addr = 173, cosine_out = 0x379b5 = -0.524590
        9'h0ae: cosine_out = 16'hddc2; // addr = 174, cosine_out = 0x3770b = -0.534998
        9'h0af: cosine_out = 16'hdd19; // addr = 175, cosine_out = 0x37466 = -0.545325
        9'h0b0: cosine_out = 16'hdc71; // addr = 176, cosine_out = 0x371c7 = -0.555570
        9'h0b1: cosine_out = 16'hdbcb; // addr = 177, cosine_out = 0x36f2d = -0.565732
        9'h0b2: cosine_out = 16'hdb26; // addr = 178, cosine_out = 0x36c98 = -0.575808
        9'h0b3: cosine_out = 16'hda82; // addr = 179, cosine_out = 0x36a0a = -0.585798
        9'h0b4: cosine_out = 16'hd9e0; // addr = 180, cosine_out = 0x36781 = -0.595699
        9'h0b5: cosine_out = 16'hd93f; // addr = 181, cosine_out = 0x364fe = -0.605511
        9'h0b6: cosine_out = 16'hd8a0; // addr = 182, cosine_out = 0x36281 = -0.615232
        9'h0b7: cosine_out = 16'hd802; // addr = 183, cosine_out = 0x3600a = -0.624860
        9'h0b8: cosine_out = 16'hd766; // addr = 184, cosine_out = 0x35d99 = -0.634393
        9'h0b9: cosine_out = 16'hd6cb; // addr = 185, cosine_out = 0x35b2e = -0.643832
        9'h0ba: cosine_out = 16'hd632; // addr = 186, cosine_out = 0x358ca = -0.653173
        9'h0bb: cosine_out = 16'hd59b; // addr = 187, cosine_out = 0x3566c = -0.662416
        9'h0bc: cosine_out = 16'hd505; // addr = 188, cosine_out = 0x35415 = -0.671559
        9'h0bd: cosine_out = 16'hd471; // addr = 189, cosine_out = 0x351c5 = -0.680601
        9'h0be: cosine_out = 16'hd3de; // addr = 190, cosine_out = 0x34f7b = -0.689541
        9'h0bf: cosine_out = 16'hd34e; // addr = 191, cosine_out = 0x34d38 = -0.698376
        9'h0c0: cosine_out = 16'hd2bf; // addr = 192, cosine_out = 0x34afc = -0.707107
        9'h0c1: cosine_out = 16'hd231; // addr = 193, cosine_out = 0x348c6 = -0.715731
        9'h0c2: cosine_out = 16'hd1a6; // addr = 194, cosine_out = 0x34698 = -0.724247
        9'h0c3: cosine_out = 16'hd11c; // addr = 195, cosine_out = 0x34471 = -0.732654
        9'h0c4: cosine_out = 16'hd094; // addr = 196, cosine_out = 0x34252 = -0.740951
        9'h0c5: cosine_out = 16'hd00e; // addr = 197, cosine_out = 0x34039 = -0.749136
        9'h0c6: cosine_out = 16'hcf8a; // addr = 198, cosine_out = 0x33e28 = -0.757209
        9'h0c7: cosine_out = 16'hcf07; // addr = 199, cosine_out = 0x33c1e = -0.765167
        9'h0c8: cosine_out = 16'hce87; // addr = 200, cosine_out = 0x33a1c = -0.773010
        9'h0c9: cosine_out = 16'hce08; // addr = 201, cosine_out = 0x33822 = -0.780737
        9'h0ca: cosine_out = 16'hcd8b; // addr = 202, cosine_out = 0x3362f = -0.788346
        9'h0cb: cosine_out = 16'hcd11; // addr = 203, cosine_out = 0x33445 = -0.795837
        9'h0cc: cosine_out = 16'hcc98; // addr = 204, cosine_out = 0x33261 = -0.803208
        9'h0cd: cosine_out = 16'hcc21; // addr = 205, cosine_out = 0x33086 = -0.810457
        9'h0ce: cosine_out = 16'hcbac; // addr = 206, cosine_out = 0x32eb3 = -0.817585
        9'h0cf: cosine_out = 16'hcb3a; // addr = 207, cosine_out = 0x32ce8 = -0.824589
        9'h0d0: cosine_out = 16'hcac9; // addr = 208, cosine_out = 0x32b25 = -0.831470
        9'h0d1: cosine_out = 16'hca5a; // addr = 209, cosine_out = 0x3296b = -0.838225
        9'h0d2: cosine_out = 16'hc9ee; // addr = 210, cosine_out = 0x327b8 = -0.844854
        9'h0d3: cosine_out = 16'hc983; // addr = 211, cosine_out = 0x3260e = -0.851355
        9'h0d4: cosine_out = 16'hc91b; // addr = 212, cosine_out = 0x3246c = -0.857729
        9'h0d5: cosine_out = 16'hc8b4; // addr = 213, cosine_out = 0x322d3 = -0.863973
        9'h0d6: cosine_out = 16'hc850; // addr = 214, cosine_out = 0x32142 = -0.870087
        9'h0d7: cosine_out = 16'hc7ee; // addr = 215, cosine_out = 0x31fba = -0.876070
        9'h0d8: cosine_out = 16'hc78e; // addr = 216, cosine_out = 0x31e3b = -0.881921
        9'h0d9: cosine_out = 16'hc731; // addr = 217, cosine_out = 0x31cc4 = -0.887640
        9'h0da: cosine_out = 16'hc6d5; // addr = 218, cosine_out = 0x31b56 = -0.893224
        9'h0db: cosine_out = 16'hc67c; // addr = 219, cosine_out = 0x319f1 = -0.898674
        9'h0dc: cosine_out = 16'hc625; // addr = 220, cosine_out = 0x31895 = -0.903989
        9'h0dd: cosine_out = 16'hc5d0; // addr = 221, cosine_out = 0x31741 = -0.909168
        9'h0de: cosine_out = 16'hc57d; // addr = 222, cosine_out = 0x315f7 = -0.914210
        9'h0df: cosine_out = 16'hc52d; // addr = 223, cosine_out = 0x314b5 = -0.919114
        9'h0e0: cosine_out = 16'hc4df; // addr = 224, cosine_out = 0x3137d = -0.923880
        9'h0e1: cosine_out = 16'hc493; // addr = 225, cosine_out = 0x3124e = -0.928506
        9'h0e2: cosine_out = 16'hc44a; // addr = 226, cosine_out = 0x31128 = -0.932993
        9'h0e3: cosine_out = 16'hc402; // addr = 227, cosine_out = 0x3100b = -0.937339
        9'h0e4: cosine_out = 16'hc3bd; // addr = 228, cosine_out = 0x30ef7 = -0.941544
        9'h0e5: cosine_out = 16'hc37b; // addr = 229, cosine_out = 0x30ded = -0.945607
        9'h0e6: cosine_out = 16'hc33b; // addr = 230, cosine_out = 0x30cec = -0.949528
        9'h0e7: cosine_out = 16'hc2fd; // addr = 231, cosine_out = 0x30bf5 = -0.953306
        9'h0e8: cosine_out = 16'hc2c1; // addr = 232, cosine_out = 0x30b06 = -0.956940
        9'h0e9: cosine_out = 16'hc288; // addr = 233, cosine_out = 0x30a22 = -0.960431
        9'h0ea: cosine_out = 16'hc251; // addr = 234, cosine_out = 0x30946 = -0.963776
        9'h0eb: cosine_out = 16'hc21d; // addr = 235, cosine_out = 0x30875 = -0.966976
        9'h0ec: cosine_out = 16'hc1eb; // addr = 236, cosine_out = 0x307ad = -0.970031
        9'h0ed: cosine_out = 16'hc1bb; // addr = 237, cosine_out = 0x306ee = -0.972940
        9'h0ee: cosine_out = 16'hc18e; // addr = 238, cosine_out = 0x30639 = -0.975702
        9'h0ef: cosine_out = 16'hc163; // addr = 239, cosine_out = 0x3058d = -0.978317
        9'h0f0: cosine_out = 16'hc13b; // addr = 240, cosine_out = 0x304ec = -0.980785
        9'h0f1: cosine_out = 16'hc115; // addr = 241, cosine_out = 0x30454 = -0.983105
        9'h0f2: cosine_out = 16'hc0f1; // addr = 242, cosine_out = 0x303c5 = -0.985278
        9'h0f3: cosine_out = 16'hc0d0; // addr = 243, cosine_out = 0x30341 = -0.987301
        9'h0f4: cosine_out = 16'hc0b1; // addr = 244, cosine_out = 0x302c6 = -0.989177
        9'h0f5: cosine_out = 16'hc095; // addr = 245, cosine_out = 0x30255 = -0.990903
        9'h0f6: cosine_out = 16'hc07b; // addr = 246, cosine_out = 0x301ed = -0.992480
        9'h0f7: cosine_out = 16'hc064; // addr = 247, cosine_out = 0x30190 = -0.993907
        9'h0f8: cosine_out = 16'hc04f; // addr = 248, cosine_out = 0x3013c = -0.995185
        9'h0f9: cosine_out = 16'hc03c; // addr = 249, cosine_out = 0x300f2 = -0.996313
        9'h0fa: cosine_out = 16'hc02c; // addr = 250, cosine_out = 0x300b2 = -0.997290
        9'h0fb: cosine_out = 16'hc01f; // addr = 251, cosine_out = 0x3007c = -0.998118
        9'h0fc: cosine_out = 16'hc013; // addr = 252, cosine_out = 0x3004f = -0.998795
        9'h0fd: cosine_out = 16'hc00b; // addr = 253, cosine_out = 0x3002d = -0.999322
        9'h0fe: cosine_out = 16'hc005; // addr = 254, cosine_out = 0x30014 = -0.999699
        9'h0ff: cosine_out = 16'hc001; // addr = 255, cosine_out = 0x30005 = -0.999925
        9'h100: cosine_out = 16'hc000; // addr = 256, cosine_out = 0x30000 = -1.000000
        9'h101: cosine_out = 16'hc001; // addr = 257, cosine_out = 0x30005 = -0.999925
        9'h102: cosine_out = 16'hc005; // addr = 258, cosine_out = 0x30014 = -0.999699
        9'h103: cosine_out = 16'hc00b; // addr = 259, cosine_out = 0x3002d = -0.999322
        9'h104: cosine_out = 16'hc013; // addr = 260, cosine_out = 0x3004f = -0.998795
        9'h105: cosine_out = 16'hc01f; // addr = 261, cosine_out = 0x3007c = -0.998118
        9'h106: cosine_out = 16'hc02c; // addr = 262, cosine_out = 0x300b2 = -0.997290
        9'h107: cosine_out = 16'hc03c; // addr = 263, cosine_out = 0x300f2 = -0.996313
        9'h108: cosine_out = 16'hc04f; // addr = 264, cosine_out = 0x3013c = -0.995185
        9'h109: cosine_out = 16'hc064; // addr = 265, cosine_out = 0x30190 = -0.993907
        9'h10a: cosine_out = 16'hc07b; // addr = 266, cosine_out = 0x301ed = -0.992480
        9'h10b: cosine_out = 16'hc095; // addr = 267, cosine_out = 0x30255 = -0.990903
        9'h10c: cosine_out = 16'hc0b1; // addr = 268, cosine_out = 0x302c6 = -0.989177
        9'h10d: cosine_out = 16'hc0d0; // addr = 269, cosine_out = 0x30341 = -0.987301
        9'h10e: cosine_out = 16'hc0f1; // addr = 270, cosine_out = 0x303c5 = -0.985278
        9'h10f: cosine_out = 16'hc115; // addr = 271, cosine_out = 0x30454 = -0.983105
        9'h110: cosine_out = 16'hc13b; // addr = 272, cosine_out = 0x304ec = -0.980785
        9'h111: cosine_out = 16'hc163; // addr = 273, cosine_out = 0x3058d = -0.978317
        9'h112: cosine_out = 16'hc18e; // addr = 274, cosine_out = 0x30639 = -0.975702
        9'h113: cosine_out = 16'hc1bb; // addr = 275, cosine_out = 0x306ee = -0.972940
        9'h114: cosine_out = 16'hc1eb; // addr = 276, cosine_out = 0x307ad = -0.970031
        9'h115: cosine_out = 16'hc21d; // addr = 277, cosine_out = 0x30875 = -0.966976
        9'h116: cosine_out = 16'hc251; // addr = 278, cosine_out = 0x30946 = -0.963776
        9'h117: cosine_out = 16'hc288; // addr = 279, cosine_out = 0x30a22 = -0.960431
        9'h118: cosine_out = 16'hc2c1; // addr = 280, cosine_out = 0x30b06 = -0.956940
        9'h119: cosine_out = 16'hc2fd; // addr = 281, cosine_out = 0x30bf5 = -0.953306
        9'h11a: cosine_out = 16'hc33b; // addr = 282, cosine_out = 0x30cec = -0.949528
        9'h11b: cosine_out = 16'hc37b; // addr = 283, cosine_out = 0x30ded = -0.945607
        9'h11c: cosine_out = 16'hc3bd; // addr = 284, cosine_out = 0x30ef7 = -0.941544
        9'h11d: cosine_out = 16'hc402; // addr = 285, cosine_out = 0x3100b = -0.937339
        9'h11e: cosine_out = 16'hc44a; // addr = 286, cosine_out = 0x31128 = -0.932993
        9'h11f: cosine_out = 16'hc493; // addr = 287, cosine_out = 0x3124e = -0.928506
        9'h120: cosine_out = 16'hc4df; // addr = 288, cosine_out = 0x3137d = -0.923880
        9'h121: cosine_out = 16'hc52d; // addr = 289, cosine_out = 0x314b5 = -0.919114
        9'h122: cosine_out = 16'hc57d; // addr = 290, cosine_out = 0x315f7 = -0.914210
        9'h123: cosine_out = 16'hc5d0; // addr = 291, cosine_out = 0x31741 = -0.909168
        9'h124: cosine_out = 16'hc625; // addr = 292, cosine_out = 0x31895 = -0.903989
        9'h125: cosine_out = 16'hc67c; // addr = 293, cosine_out = 0x319f1 = -0.898674
        9'h126: cosine_out = 16'hc6d5; // addr = 294, cosine_out = 0x31b56 = -0.893224
        9'h127: cosine_out = 16'hc731; // addr = 295, cosine_out = 0x31cc4 = -0.887640
        9'h128: cosine_out = 16'hc78e; // addr = 296, cosine_out = 0x31e3b = -0.881921
        9'h129: cosine_out = 16'hc7ee; // addr = 297, cosine_out = 0x31fba = -0.876070
        9'h12a: cosine_out = 16'hc850; // addr = 298, cosine_out = 0x32142 = -0.870087
        9'h12b: cosine_out = 16'hc8b4; // addr = 299, cosine_out = 0x322d3 = -0.863973
        9'h12c: cosine_out = 16'hc91b; // addr = 300, cosine_out = 0x3246c = -0.857729
        9'h12d: cosine_out = 16'hc983; // addr = 301, cosine_out = 0x3260e = -0.851355
        9'h12e: cosine_out = 16'hc9ee; // addr = 302, cosine_out = 0x327b8 = -0.844854
        9'h12f: cosine_out = 16'hca5a; // addr = 303, cosine_out = 0x3296b = -0.838225
        9'h130: cosine_out = 16'hcac9; // addr = 304, cosine_out = 0x32b25 = -0.831470
        9'h131: cosine_out = 16'hcb3a; // addr = 305, cosine_out = 0x32ce8 = -0.824589
        9'h132: cosine_out = 16'hcbac; // addr = 306, cosine_out = 0x32eb3 = -0.817585
        9'h133: cosine_out = 16'hcc21; // addr = 307, cosine_out = 0x33086 = -0.810457
        9'h134: cosine_out = 16'hcc98; // addr = 308, cosine_out = 0x33261 = -0.803208
        9'h135: cosine_out = 16'hcd11; // addr = 309, cosine_out = 0x33445 = -0.795837
        9'h136: cosine_out = 16'hcd8b; // addr = 310, cosine_out = 0x3362f = -0.788346
        9'h137: cosine_out = 16'hce08; // addr = 311, cosine_out = 0x33822 = -0.780737
        9'h138: cosine_out = 16'hce87; // addr = 312, cosine_out = 0x33a1c = -0.773010
        9'h139: cosine_out = 16'hcf07; // addr = 313, cosine_out = 0x33c1e = -0.765167
        9'h13a: cosine_out = 16'hcf8a; // addr = 314, cosine_out = 0x33e28 = -0.757209
        9'h13b: cosine_out = 16'hd00e; // addr = 315, cosine_out = 0x34039 = -0.749136
        9'h13c: cosine_out = 16'hd094; // addr = 316, cosine_out = 0x34252 = -0.740951
        9'h13d: cosine_out = 16'hd11c; // addr = 317, cosine_out = 0x34471 = -0.732654
        9'h13e: cosine_out = 16'hd1a6; // addr = 318, cosine_out = 0x34698 = -0.724247
        9'h13f: cosine_out = 16'hd231; // addr = 319, cosine_out = 0x348c6 = -0.715731
        9'h140: cosine_out = 16'hd2bf; // addr = 320, cosine_out = 0x34afc = -0.707107
        9'h141: cosine_out = 16'hd34e; // addr = 321, cosine_out = 0x34d38 = -0.698376
        9'h142: cosine_out = 16'hd3de; // addr = 322, cosine_out = 0x34f7b = -0.689541
        9'h143: cosine_out = 16'hd471; // addr = 323, cosine_out = 0x351c5 = -0.680601
        9'h144: cosine_out = 16'hd505; // addr = 324, cosine_out = 0x35415 = -0.671559
        9'h145: cosine_out = 16'hd59b; // addr = 325, cosine_out = 0x3566c = -0.662416
        9'h146: cosine_out = 16'hd632; // addr = 326, cosine_out = 0x358ca = -0.653173
        9'h147: cosine_out = 16'hd6cb; // addr = 327, cosine_out = 0x35b2e = -0.643832
        9'h148: cosine_out = 16'hd766; // addr = 328, cosine_out = 0x35d99 = -0.634393
        9'h149: cosine_out = 16'hd802; // addr = 329, cosine_out = 0x3600a = -0.624860
        9'h14a: cosine_out = 16'hd8a0; // addr = 330, cosine_out = 0x36281 = -0.615232
        9'h14b: cosine_out = 16'hd93f; // addr = 331, cosine_out = 0x364fe = -0.605511
        9'h14c: cosine_out = 16'hd9e0; // addr = 332, cosine_out = 0x36781 = -0.595699
        9'h14d: cosine_out = 16'hda82; // addr = 333, cosine_out = 0x36a0a = -0.585798
        9'h14e: cosine_out = 16'hdb26; // addr = 334, cosine_out = 0x36c98 = -0.575808
        9'h14f: cosine_out = 16'hdbcb; // addr = 335, cosine_out = 0x36f2d = -0.565732
        9'h150: cosine_out = 16'hdc71; // addr = 336, cosine_out = 0x371c7 = -0.555570
        9'h151: cosine_out = 16'hdd19; // addr = 337, cosine_out = 0x37466 = -0.545325
        9'h152: cosine_out = 16'hddc2; // addr = 338, cosine_out = 0x3770b = -0.534998
        9'h153: cosine_out = 16'hde6d; // addr = 339, cosine_out = 0x379b5 = -0.524590
        9'h154: cosine_out = 16'hdf19; // addr = 340, cosine_out = 0x37c64 = -0.514103
        9'h155: cosine_out = 16'hdfc6; // addr = 341, cosine_out = 0x37f19 = -0.503538
        9'h156: cosine_out = 16'he074; // addr = 342, cosine_out = 0x381d2 = -0.492898
        9'h157: cosine_out = 16'he124; // addr = 343, cosine_out = 0x38490 = -0.482184
        9'h158: cosine_out = 16'he1d4; // addr = 344, cosine_out = 0x38753 = -0.471397
        9'h159: cosine_out = 16'he286; // addr = 345, cosine_out = 0x38a1b = -0.460539
        9'h15a: cosine_out = 16'he339; // addr = 346, cosine_out = 0x38ce7 = -0.449611
        9'h15b: cosine_out = 16'he3ed; // addr = 347, cosine_out = 0x38fb7 = -0.438616
        9'h15c: cosine_out = 16'he4a3; // addr = 348, cosine_out = 0x3928c = -0.427555
        9'h15d: cosine_out = 16'he559; // addr = 349, cosine_out = 0x39565 = -0.416430
        9'h15e: cosine_out = 16'he610; // addr = 350, cosine_out = 0x39843 = -0.405241
        9'h15f: cosine_out = 16'he6c9; // addr = 351, cosine_out = 0x39b24 = -0.393992
        9'h160: cosine_out = 16'he782; // addr = 352, cosine_out = 0x39e09 = -0.382683
        9'h161: cosine_out = 16'he83c; // addr = 353, cosine_out = 0x3a0f2 = -0.371317
        9'h162: cosine_out = 16'he8f7; // addr = 354, cosine_out = 0x3a3de = -0.359895
        9'h163: cosine_out = 16'he9b3; // addr = 355, cosine_out = 0x3a6cf = -0.348419
        9'h164: cosine_out = 16'hea70; // addr = 356, cosine_out = 0x3a9c2 = -0.336890
        9'h165: cosine_out = 16'heb2e; // addr = 357, cosine_out = 0x3acb9 = -0.325310
        9'h166: cosine_out = 16'hebec; // addr = 358, cosine_out = 0x3afb3 = -0.313682
        9'h167: cosine_out = 16'hecac; // addr = 359, cosine_out = 0x3b2b0 = -0.302006
        9'h168: cosine_out = 16'hed6c; // addr = 360, cosine_out = 0x3b5b0 = -0.290285
        9'h169: cosine_out = 16'hee2c; // addr = 361, cosine_out = 0x3b8b3 = -0.278520
        9'h16a: cosine_out = 16'heeee; // addr = 362, cosine_out = 0x3bbb9 = -0.266713
        9'h16b: cosine_out = 16'hefb0; // addr = 363, cosine_out = 0x3bec2 = -0.254866
        9'h16c: cosine_out = 16'hf073; // addr = 364, cosine_out = 0x3c1cd = -0.242980
        9'h16d: cosine_out = 16'hf136; // addr = 365, cosine_out = 0x3c4da = -0.231058
        9'h16e: cosine_out = 16'hf1fa; // addr = 366, cosine_out = 0x3c7e9 = -0.219101
        9'h16f: cosine_out = 16'hf2be; // addr = 367, cosine_out = 0x3cafb = -0.207111
        9'h170: cosine_out = 16'hf383; // addr = 368, cosine_out = 0x3ce0f = -0.195090
        9'h171: cosine_out = 16'hf449; // addr = 369, cosine_out = 0x3d125 = -0.183040
        9'h172: cosine_out = 16'hf50f; // addr = 370, cosine_out = 0x3d43c = -0.170962
        9'h173: cosine_out = 16'hf5d5; // addr = 371, cosine_out = 0x3d756 = -0.158858
        9'h174: cosine_out = 16'hf69c; // addr = 372, cosine_out = 0x3da70 = -0.146730
        9'h175: cosine_out = 16'hf763; // addr = 373, cosine_out = 0x3dd8d = -0.134581
        9'h176: cosine_out = 16'hf82a; // addr = 374, cosine_out = 0x3e0aa = -0.122411
        9'h177: cosine_out = 16'hf8f2; // addr = 375, cosine_out = 0x3e3c9 = -0.110222
        9'h178: cosine_out = 16'hf9ba; // addr = 376, cosine_out = 0x3e6e9 = -0.098017
        9'h179: cosine_out = 16'hfa82; // addr = 377, cosine_out = 0x3ea0a = -0.085797
        9'h17a: cosine_out = 16'hfb4a; // addr = 378, cosine_out = 0x3ed2b = -0.073565
        9'h17b: cosine_out = 16'hfc13; // addr = 379, cosine_out = 0x3f04e = -0.061321
        9'h17c: cosine_out = 16'hfcdc; // addr = 380, cosine_out = 0x3f371 = -0.049068
        9'h17d: cosine_out = 16'hfda5; // addr = 381, cosine_out = 0x3f694 = -0.036807
        9'h17e: cosine_out = 16'hfe6e; // addr = 382, cosine_out = 0x3f9b8 = -0.024541
        9'h17f: cosine_out = 16'hff37; // addr = 383, cosine_out = 0x3fcdc = -0.012272
        9'h180: cosine_out = 16'h8000; // addr = 384, cosine_out = 0x20000 = -0.000000
        9'h181: cosine_out = 16'h00c9; // addr = 385, cosine_out = 0x00324 = 0.012272
        9'h182: cosine_out = 16'h0192; // addr = 386, cosine_out = 0x00648 = 0.024541
        9'h183: cosine_out = 16'h025b; // addr = 387, cosine_out = 0x0096c = 0.036807
        9'h184: cosine_out = 16'h0323; // addr = 388, cosine_out = 0x00c8f = 0.049068
        9'h185: cosine_out = 16'h03ec; // addr = 389, cosine_out = 0x00fb2 = 0.061321
        9'h186: cosine_out = 16'h04b5; // addr = 390, cosine_out = 0x012d5 = 0.073565
        9'h187: cosine_out = 16'h057d; // addr = 391, cosine_out = 0x015f6 = 0.085797
        9'h188: cosine_out = 16'h0645; // addr = 392, cosine_out = 0x01917 = 0.098017
        9'h189: cosine_out = 16'h070d; // addr = 393, cosine_out = 0x01c37 = 0.110222
        9'h18a: cosine_out = 16'h07d5; // addr = 394, cosine_out = 0x01f56 = 0.122411
        9'h18b: cosine_out = 16'h089c; // addr = 395, cosine_out = 0x02273 = 0.134581
        9'h18c: cosine_out = 16'h0964; // addr = 396, cosine_out = 0x02590 = 0.146730
        9'h18d: cosine_out = 16'h0a2a; // addr = 397, cosine_out = 0x028aa = 0.158858
        9'h18e: cosine_out = 16'h0af1; // addr = 398, cosine_out = 0x02bc4 = 0.170962
        9'h18f: cosine_out = 16'h0bb6; // addr = 399, cosine_out = 0x02edb = 0.183040
        9'h190: cosine_out = 16'h0c7c; // addr = 400, cosine_out = 0x031f1 = 0.195090
        9'h191: cosine_out = 16'h0d41; // addr = 401, cosine_out = 0x03505 = 0.207111
        9'h192: cosine_out = 16'h0e05; // addr = 402, cosine_out = 0x03817 = 0.219101
        9'h193: cosine_out = 16'h0ec9; // addr = 403, cosine_out = 0x03b26 = 0.231058
        9'h194: cosine_out = 16'h0f8c; // addr = 404, cosine_out = 0x03e33 = 0.242980
        9'h195: cosine_out = 16'h104f; // addr = 405, cosine_out = 0x0413e = 0.254866
        9'h196: cosine_out = 16'h1111; // addr = 406, cosine_out = 0x04447 = 0.266713
        9'h197: cosine_out = 16'h11d3; // addr = 407, cosine_out = 0x0474d = 0.278520
        9'h198: cosine_out = 16'h1294; // addr = 408, cosine_out = 0x04a50 = 0.290285
        9'h199: cosine_out = 16'h1354; // addr = 409, cosine_out = 0x04d50 = 0.302006
        9'h19a: cosine_out = 16'h1413; // addr = 410, cosine_out = 0x0504d = 0.313682
        9'h19b: cosine_out = 16'h14d1; // addr = 411, cosine_out = 0x05347 = 0.325310
        9'h19c: cosine_out = 16'h158f; // addr = 412, cosine_out = 0x0563e = 0.336890
        9'h19d: cosine_out = 16'h164c; // addr = 413, cosine_out = 0x05931 = 0.348419
        9'h19e: cosine_out = 16'h1708; // addr = 414, cosine_out = 0x05c22 = 0.359895
        9'h19f: cosine_out = 16'h17c3; // addr = 415, cosine_out = 0x05f0e = 0.371317
        9'h1a0: cosine_out = 16'h187d; // addr = 416, cosine_out = 0x061f7 = 0.382683
        9'h1a1: cosine_out = 16'h1937; // addr = 417, cosine_out = 0x064dc = 0.393992
        9'h1a2: cosine_out = 16'h19ef; // addr = 418, cosine_out = 0x067bd = 0.405241
        9'h1a3: cosine_out = 16'h1aa6; // addr = 419, cosine_out = 0x06a9b = 0.416430
        9'h1a4: cosine_out = 16'h1b5d; // addr = 420, cosine_out = 0x06d74 = 0.427555
        9'h1a5: cosine_out = 16'h1c12; // addr = 421, cosine_out = 0x07049 = 0.438616
        9'h1a6: cosine_out = 16'h1cc6; // addr = 422, cosine_out = 0x07319 = 0.449611
        9'h1a7: cosine_out = 16'h1d79; // addr = 423, cosine_out = 0x075e5 = 0.460539
        9'h1a8: cosine_out = 16'h1e2b; // addr = 424, cosine_out = 0x078ad = 0.471397
        9'h1a9: cosine_out = 16'h1edc; // addr = 425, cosine_out = 0x07b70 = 0.482184
        9'h1aa: cosine_out = 16'h1f8b; // addr = 426, cosine_out = 0x07e2e = 0.492898
        9'h1ab: cosine_out = 16'h2039; // addr = 427, cosine_out = 0x080e7 = 0.503538
        9'h1ac: cosine_out = 16'h20e7; // addr = 428, cosine_out = 0x0839c = 0.514103
        9'h1ad: cosine_out = 16'h2192; // addr = 429, cosine_out = 0x0864b = 0.524590
        9'h1ae: cosine_out = 16'h223d; // addr = 430, cosine_out = 0x088f5 = 0.534998
        9'h1af: cosine_out = 16'h22e6; // addr = 431, cosine_out = 0x08b9a = 0.545325
        9'h1b0: cosine_out = 16'h238e; // addr = 432, cosine_out = 0x08e39 = 0.555570
        9'h1b1: cosine_out = 16'h2434; // addr = 433, cosine_out = 0x090d3 = 0.565732
        9'h1b2: cosine_out = 16'h24da; // addr = 434, cosine_out = 0x09368 = 0.575808
        9'h1b3: cosine_out = 16'h257d; // addr = 435, cosine_out = 0x095f6 = 0.585798
        9'h1b4: cosine_out = 16'h261f; // addr = 436, cosine_out = 0x0987f = 0.595699
        9'h1b5: cosine_out = 16'h26c0; // addr = 437, cosine_out = 0x09b02 = 0.605511
        9'h1b6: cosine_out = 16'h275f; // addr = 438, cosine_out = 0x09d7f = 0.615232
        9'h1b7: cosine_out = 16'h27fd; // addr = 439, cosine_out = 0x09ff6 = 0.624860
        9'h1b8: cosine_out = 16'h2899; // addr = 440, cosine_out = 0x0a267 = 0.634393
        9'h1b9: cosine_out = 16'h2934; // addr = 441, cosine_out = 0x0a4d2 = 0.643832
        9'h1ba: cosine_out = 16'h29cd; // addr = 442, cosine_out = 0x0a736 = 0.653173
        9'h1bb: cosine_out = 16'h2a65; // addr = 443, cosine_out = 0x0a994 = 0.662416
        9'h1bc: cosine_out = 16'h2afa; // addr = 444, cosine_out = 0x0abeb = 0.671559
        9'h1bd: cosine_out = 16'h2b8e; // addr = 445, cosine_out = 0x0ae3b = 0.680601
        9'h1be: cosine_out = 16'h2c21; // addr = 446, cosine_out = 0x0b085 = 0.689541
        9'h1bf: cosine_out = 16'h2cb2; // addr = 447, cosine_out = 0x0b2c8 = 0.698376
        9'h1c0: cosine_out = 16'h2d41; // addr = 448, cosine_out = 0x0b504 = 0.707107
        9'h1c1: cosine_out = 16'h2dce; // addr = 449, cosine_out = 0x0b73a = 0.715731
        9'h1c2: cosine_out = 16'h2e5a; // addr = 450, cosine_out = 0x0b968 = 0.724247
        9'h1c3: cosine_out = 16'h2ee3; // addr = 451, cosine_out = 0x0bb8f = 0.732654
        9'h1c4: cosine_out = 16'h2f6b; // addr = 452, cosine_out = 0x0bdae = 0.740951
        9'h1c5: cosine_out = 16'h2ff1; // addr = 453, cosine_out = 0x0bfc7 = 0.749136
        9'h1c6: cosine_out = 16'h3076; // addr = 454, cosine_out = 0x0c1d8 = 0.757209
        9'h1c7: cosine_out = 16'h30f8; // addr = 455, cosine_out = 0x0c3e2 = 0.765167
        9'h1c8: cosine_out = 16'h3179; // addr = 456, cosine_out = 0x0c5e4 = 0.773010
        9'h1c9: cosine_out = 16'h31f7; // addr = 457, cosine_out = 0x0c7de = 0.780737
        9'h1ca: cosine_out = 16'h3274; // addr = 458, cosine_out = 0x0c9d1 = 0.788346
        9'h1cb: cosine_out = 16'h32ee; // addr = 459, cosine_out = 0x0cbbb = 0.795837
        9'h1cc: cosine_out = 16'h3367; // addr = 460, cosine_out = 0x0cd9f = 0.803208
        9'h1cd: cosine_out = 16'h33de; // addr = 461, cosine_out = 0x0cf7a = 0.810457
        9'h1ce: cosine_out = 16'h3453; // addr = 462, cosine_out = 0x0d14d = 0.817585
        9'h1cf: cosine_out = 16'h34c6; // addr = 463, cosine_out = 0x0d318 = 0.824589
        9'h1d0: cosine_out = 16'h3536; // addr = 464, cosine_out = 0x0d4db = 0.831470
        9'h1d1: cosine_out = 16'h35a5; // addr = 465, cosine_out = 0x0d695 = 0.838225
        9'h1d2: cosine_out = 16'h3612; // addr = 466, cosine_out = 0x0d848 = 0.844854
        9'h1d3: cosine_out = 16'h367c; // addr = 467, cosine_out = 0x0d9f2 = 0.851355
        9'h1d4: cosine_out = 16'h36e5; // addr = 468, cosine_out = 0x0db94 = 0.857729
        9'h1d5: cosine_out = 16'h374b; // addr = 469, cosine_out = 0x0dd2d = 0.863973
        9'h1d6: cosine_out = 16'h37af; // addr = 470, cosine_out = 0x0debe = 0.870087
        9'h1d7: cosine_out = 16'h3811; // addr = 471, cosine_out = 0x0e046 = 0.876070
        9'h1d8: cosine_out = 16'h3871; // addr = 472, cosine_out = 0x0e1c5 = 0.881921
        9'h1d9: cosine_out = 16'h38cf; // addr = 473, cosine_out = 0x0e33c = 0.887640
        9'h1da: cosine_out = 16'h392a; // addr = 474, cosine_out = 0x0e4aa = 0.893224
        9'h1db: cosine_out = 16'h3983; // addr = 475, cosine_out = 0x0e60f = 0.898674
        9'h1dc: cosine_out = 16'h39da; // addr = 476, cosine_out = 0x0e76b = 0.903989
        9'h1dd: cosine_out = 16'h3a2f; // addr = 477, cosine_out = 0x0e8bf = 0.909168
        9'h1de: cosine_out = 16'h3a82; // addr = 478, cosine_out = 0x0ea09 = 0.914210
        9'h1df: cosine_out = 16'h3ad2; // addr = 479, cosine_out = 0x0eb4b = 0.919114
        9'h1e0: cosine_out = 16'h3b20; // addr = 480, cosine_out = 0x0ec83 = 0.923880
        9'h1e1: cosine_out = 16'h3b6c; // addr = 481, cosine_out = 0x0edb2 = 0.928506
        9'h1e2: cosine_out = 16'h3bb6; // addr = 482, cosine_out = 0x0eed8 = 0.932993
        9'h1e3: cosine_out = 16'h3bfd; // addr = 483, cosine_out = 0x0eff5 = 0.937339
        9'h1e4: cosine_out = 16'h3c42; // addr = 484, cosine_out = 0x0f109 = 0.941544
        9'h1e5: cosine_out = 16'h3c84; // addr = 485, cosine_out = 0x0f213 = 0.945607
        9'h1e6: cosine_out = 16'h3cc5; // addr = 486, cosine_out = 0x0f314 = 0.949528
        9'h1e7: cosine_out = 16'h3d02; // addr = 487, cosine_out = 0x0f40b = 0.953306
        9'h1e8: cosine_out = 16'h3d3e; // addr = 488, cosine_out = 0x0f4fa = 0.956940
        9'h1e9: cosine_out = 16'h3d77; // addr = 489, cosine_out = 0x0f5de = 0.960431
        9'h1ea: cosine_out = 16'h3dae; // addr = 490, cosine_out = 0x0f6ba = 0.963776
        9'h1eb: cosine_out = 16'h3de2; // addr = 491, cosine_out = 0x0f78b = 0.966976
        9'h1ec: cosine_out = 16'h3e14; // addr = 492, cosine_out = 0x0f853 = 0.970031
        9'h1ed: cosine_out = 16'h3e44; // addr = 493, cosine_out = 0x0f912 = 0.972940
        9'h1ee: cosine_out = 16'h3e71; // addr = 494, cosine_out = 0x0f9c7 = 0.975702
        9'h1ef: cosine_out = 16'h3e9c; // addr = 495, cosine_out = 0x0fa73 = 0.978317
        9'h1f0: cosine_out = 16'h3ec5; // addr = 496, cosine_out = 0x0fb14 = 0.980785
        9'h1f1: cosine_out = 16'h3eeb; // addr = 497, cosine_out = 0x0fbac = 0.983105
        9'h1f2: cosine_out = 16'h3f0e; // addr = 498, cosine_out = 0x0fc3b = 0.985278
        9'h1f3: cosine_out = 16'h3f2f; // addr = 499, cosine_out = 0x0fcbf = 0.987301
        9'h1f4: cosine_out = 16'h3f4e; // addr = 500, cosine_out = 0x0fd3a = 0.989177
        9'h1f5: cosine_out = 16'h3f6a; // addr = 501, cosine_out = 0x0fdab = 0.990903
        9'h1f6: cosine_out = 16'h3f84; // addr = 502, cosine_out = 0x0fe13 = 0.992480
        9'h1f7: cosine_out = 16'h3f9c; // addr = 503, cosine_out = 0x0fe70 = 0.993907
        9'h1f8: cosine_out = 16'h3fb1; // addr = 504, cosine_out = 0x0fec4 = 0.995185
        9'h1f9: cosine_out = 16'h3fc3; // addr = 505, cosine_out = 0x0ff0e = 0.996313
        9'h1fa: cosine_out = 16'h3fd3; // addr = 506, cosine_out = 0x0ff4e = 0.997290
        9'h1fb: cosine_out = 16'h3fe1; // addr = 507, cosine_out = 0x0ff84 = 0.998118
        9'h1fc: cosine_out = 16'h3fec; // addr = 508, cosine_out = 0x0ffb1 = 0.998795
        9'h1fd: cosine_out = 16'h3ff4; // addr = 509, cosine_out = 0x0ffd3 = 0.999322
        9'h1fe: cosine_out = 16'h3ffb; // addr = 510, cosine_out = 0x0ffec = 0.999699
        9'h1ff: cosine_out = 16'h3ffe; // addr = 511, cosine_out = 0x0fffb = 0.999925
      endcase // case (cosine_addr)
      //$display("cosine_addr = %h = %d, cosine_out = %h = %d", cosine_addr, cosine_addr, cosine_out, cosine_out);
   end // always @ (posedge CLK)
endmodule // cosineTable9x16bit
